Contributions are welcome either as pull requests or as bug reports. If reporting a bug please include the exact code you used and if applicable the bibcodes for any paper you where trying to access.
